# Kurama
Logic is Panic's prey.

This is the next generation of memeing. Complete analysis of current
memes using a suite of advanced machine learning methods, including
deep neural nets and evolutionary approaches.

# Credit
Credit goes to James Bennett (https://github.com/ubernostrum)
for the original implementation.

# Changelog

## 1.0.1
Tweaks to documentation didn't get included in push to PyPI.

# License
MIT Licensed. Feel free to copy and use to your heart's content!
